==> eslint-config-osedea-4.0.0.tgz: package/lib/rules/core-stylistic-issues.js <==
// ----------------------------------------------------------------------------
// Style
// ----------------------------------------------------------------------------

module.exports = {
    // enforce linebreaks after opening and before closing array brackets
    'array-bracket-newline': [
        // TODO
        'warn',
        'consistent',
        // {
        //   multiline: true
        //   minItems: 3
        // }
    ],

    // enforce spacing inside array brackets
    'array-bracket-spacing': [
        'error',
        'never',
        {
            singleValue: false,
            objectsInArrays: false,
            arraysInArrays: false,
        },
    ],

    // enforce line breaks after each array element
    'array-element-newline': 'off', // TODO

    // disallow or enforce spaces inside of single line blocks
    'block-spacing': ['error', 'always'], // TODO

    // enforce one true brace style
    'brace-style': ['error', '1tbs', { allowSingleLine: false }],

    // require camel case names
    camelcase: [
        'error',
        {
            properties: 'always',
            ignoreDestructuring: false,
            allow: ['^UNSAFE_'],
        },
    ],

    // enforce or disallow capitalization of the first letter of a comment
    'capitalized-comments': 'off', // TODO

    // require or disallow trailing commas
    'comma-dangle': [
        'warn',
        {
            arrays: 'always-multiline',
            objects: 'always-multiline',
            imports: 'always-multiline',
            exports: 'always-multiline',
            functions: 'always-multiline',
        },
    ],

    // enforce spacing before and after comma
    'comma-spacing': ['error', { before: false, after: true }],

    // enforce one true comma style
    'comma-style': ['error', 'last'],

    // require or disallow padding inside computed properties
    'computed-property-spacing': ['error', 'never'],

    // enforce consistent naming when capturing the current execution context
    'consistent-this': 'off', // TODO

    // enforce newline at the end of file , with no multiple empty lines
    'eol-last': 'error',

    // require or disallow spacing between function identifiers and their invocations
    'func-call-spacing': 'error', // TODO

    // require function names to match the name of the variable or property to which they are assigned
    'func-name-matching': 'error',

    // require function expressions to have a name
    'func-names': 'off', // TODO

    // enforce use of function declarations or expressions
    'func-style': 'off', // TODO really not sure about this one

    // enforce consistent line breaks inside function parentheses
    'function-paren-newline': ['error', 'consistent'], // TODO multiline?

    // blacklist certain identifiers to prevent them being used
    'id-blacklist': 'off',

    // this option enforces minimum and maximum identifier lengths (variable names, property names etc.)
    'id-length': 'off',

    // require identifiers to match the provided regular expression
    'id-match': 'off',

    // enforce the location of arrow function bodies
    'implicit-arrow-linebreak': ['warn', 'beside'],

    // specify tab or space width for your code
    indent: [
        'error',
        4,
        {
            SwitchCase: 1,
            VariableDeclarator: 'first',
        },
    ],

    // specify whether double or single quotes should be used in JSX attributes
    'jsx-quotes': ['error', 'prefer-double'],

    // enforce spacing between keys and values in object literal properties
    'key-spacing': [
        // TODO
        'error',
        {
            // align: value,
            beforeColon: false,
            afterColon: true,
            mode: 'minimum',
        },
    ],

    // enforce spacing before and after keywords
    'keyword-spacing': ['error', { before: true, after: true }],

    // enforce position of line comments
    'line-comment-position': 'off', // TODO

    // disallow mixed 'LF' and 'CRLF' as linebreaks
    'linebreak-style': ['error', 'unix'],

    // require empty lines around comments
    // https://github.com/eslint/eslint/issues/2965
    'lines-around-comment': [
        'off', // TODO 1
        {
            beforeBlockComment: true,
            afterBlockComment: false,
            beforeLineComment: true,
            afterLineComment: false,
            allowBlockStart: true,
            allowBlockEnd: false,
            allowObjectStart: true,
            allowObjectEnd: false,
            allowArrayStart: true,
            allowArrayEnd: false,
            allowClassStart: true,
            allowClassEnd: true,
        },
    ],

    // require or disallow an empty line between class members
    'lines-between-class-members': ['error', 'always', { exceptAfterSingleLine: false }],

    // specify the maximum depth that blocks can be nested
    'max-depth': 'off',

    // specify the maximum length of a line in your program
    'max-len': 'off', // TODO

    // enforce a maximum file length
    'max-lines': 'off',

    // enforce a maximum number of line of code in a function
    'max-lines-per-function': 'off',

    // specify the maximum depth callbacks can be nested
    'max-nested-callbacks': 'off',

    // limits the number of parameters that can be used in the function declaration.
    'max-params': 'off',

    // specify the maximum number of statement allowed in a function
    'max-statements': 'off',

    // specify the maximum number of statements allowed per line
    'max-statements-per-line': ['error', { max: 1 }],

    // enforce a particular style for multiline comments
    'multiline-comment-style': 'off',

    // enforce newlines between operands of ternary expressions
    'multiline-ternary': ['warn', 'always-multiline'], // TODO

    // require a capital letter for constructors
    'new-cap': ['error', { newIsCap: true, capIsNew: false }],

    // disallow the omission of parentheses when invoking a constructor with no arguments
    'new-parens': 'error', // TODO

    // enforce newline after each call when chaining the calls
    'newline-per-chained-call': ['error', { ignoreChainWithDepth: 3 }], // TODO

    // disallow use of the `Array` constructor
    'no-array-constructor': 'error',

    // disallow use of bitwise operators
    'no-bitwise': 'error',

    // disallow use of the `continue` statement
    'no-continue': 'error', // TODO

    // disallow comments inline after code
    'no-inline-comments': 'off', // TODO

    // disallow `if` as the only statement in an `else` block
    'no-lonely-if': 'off', // TODO

    //  disallow mixes of different operators
    'no-mixed-operators': 'error',

    // disallow mixed spaces and tabs for indentation
    'no-mixed-spaces-and-tabs': 'error',

    // disallow use of chained assignment expressions
    'no-multi-assign': 'error',

    // disallow multiple empty lines
    'no-multiple-empty-lines': [
        0, // TODO BROKEN 2
        {
            max: 2,
            maxEOF: 1,
        },
    ],

    // disallow negated conditions
    'no-negated-condition': 'off', // TODO

    // disallow nested ternary expressions
    'no-nested-ternary': 'error',

    // disallow the use of the `Object` constructor
    'no-new-object': 'error',

    // disallow use of unary operators, `++` and `--`
    'no-plusplus': 'off', // TODO

    // disallow use of certain syntax in code
    'no-restricted-syntax': 'off', // TODO

    // disallow tabs in file
    'no-tabs': 'error',

    // disallow the use of ternary operators
    'no-ternary': 'off', // TODO

    // disallow trailing whitespace at the end of lines
    'no-trailing-spaces': ['error', { skipBlankLines: false }],

    // disallow dangling underscores in identifiers
    'no-underscore-dangle': 'off', // TODO

    // disallow the use of ternary operators when a simpler alternative exists
    'no-unneeded-ternary': ['error', { defaultAssignment: false }], // TODO

    // disallow whitespace before properties
    'no-whitespace-before-property': 'error',

    // enforce the location of single-line statements
    'nonblock-statement-body-position': ['error', 'below'],

    // enforce consistent line breaks inside braces
    'object-curly-newline': [
        // TODO
        'off',
        {
            ObjectExpression: {
                multiline: true,
                // minProperties: 1,
            },
            ObjectPattern: {
                multiline: true,
            },
        },
    ],

    // require or disallow padding inside curly braces
    'object-curly-spacing': ['error', 'always'], // TODO

    // enforce placing object properties on separate lines
    'object-property-newline': ['warn', { allowAllPropertiesOnSameLine: false }], // TODO

    // require or disallow one variable declaration per function
    'one-var': ['error', 'never'], // TODO

    // require or disallow an newline around variable declarations
    'one-var-declaration-per-line': ['error', 'always'],

    // require assignment operator shorthand where possible or prohibit it entirely
    'operator-assignment': 'off', // TODO 1

    // enforce operators to be placed before or after line breaks
    'operator-linebreak': [
        // TODO
        'warn',
        'after',
        {
            overrides: {
                '?': 'before',
                ':': 'before',
            },
        },
    ],

    // enforce padding within blocks
    'padded-blocks': [
        'error',
        {
            blocks: 'never',
            classes: 'never',
            switches: 'never',
        },
        { allowSingleLineBlocks: true },
    ],

    // require or disallow padding lines between statements
    'padding-line-between-statements': 'off', // TODO

    // disallow using Object.assign with an object literal as the first argument and prefer the use of object spread instead.
    'prefer-object-spread': 'error',

    // require quotes around object literal property names
    'quote-props': [
        // TODO
        'error',
        'as-needed',
        {
            keywords: false,
            unnecessary: true,
            numbers: false,
        },
    ],

    // specify whether backticks, double or single quotes should be used
    quotes: [
        // TODO
        'error',
        'single',
        {
            avoidEscape: true,
            allowTemplateLiterals: true,
        },
    ],

    // require or disallow use of semicolons instead of ASI
    semi: ['error', 'always'],

    // enforce spacing before and after semicolons
    'semi-spacing': ['error', { before: false, after: true }],

    // enforce location of semicolons
    'semi-style': ['error', 'last'],

    // requires object keys to be sorted
    'sort-keys': 'off', // TODO

    // sort variables within the same declaration block
    'sort-vars': 'off', // TODO

    // require or disallow a space before blocks
    'space-before-blocks': 'error',

    // require or disallow a space before function opening parenthesis
    'space-before-function-paren': [
        // TODO
        'error',
        {
            anonymous: 'always', // TODO never?
            named: 'never',
            asyncArrow: 'always',
        },
    ],

    // require or disallow spaces inside parentheses
    'space-in-parens': ['error', 'never'],

    // require spaces around operators
    'space-infix-ops': 'error',

    // require or disallow spaces before/after unary operators
    'space-unary-ops': 'error',

    // require or disallow a space immediately following the `//` or `/*` in a comment
    'spaced-comment': [
        // TODO
        'error',
        'always',
        {
            exceptions: ['-', '=', '+', '/', '*'],
            // markers: ['=', '!', '/'],
            // line: { exceptions: ['-', '='] },
            // block: { balanced: true },
        },
    ],

    // enforce spacing around colons of switch statements
    'switch-colon-spacing': ['error', { after: true, before: false }],

    // require or disallow spacing between template tags and their literals
    'template-tag-spacing': ['error', 'never'],

    // require or disallow the Unicode BOM
    'unicode-bom': ['error', 'never'],

    // require regex literals to be wrapped in parentheses
    'wrap-regex': 'error',
};

==> eslint-config-osedea-6.2.0.tgz: package/lib/rules/core-stylistic-issues.js <==
// ----------------------------------------------------------------------------
// Style
// ----------------------------------------------------------------------------

const rules = {
    // enforce linebreaks after opening and before closing array brackets
    'array-bracket-newline': [
        // TODO
        'warn',
        'consistent',
        // {
        //   multiline: true
        //   minItems: 3
        // }
    ],

    // enforce spacing inside array brackets
    'array-bracket-spacing': [
        'error',
        'never',
        {
            singleValue: false,
            objectsInArrays: false,
            arraysInArrays: false,
        },
    ],

    // enforce line breaks after each array element
    'array-element-newline': 'off', // TODO

    // disallow or enforce spaces inside of single line blocks
    'block-spacing': ['error', 'always'], // TODO

    // enforce one true brace style
    // REF typescript
    'brace-style': ['error', '1tbs', { allowSingleLine: false }],

    // require camel case names
    // REF babel
    camelcase: [
        'error',
        {
            properties: 'always',
            ignoreDestructuring: false,
            // TODO enable:
            // ignoreImports: false,
            // allow: ['^UNSAFE_'],
        },
    ],

    // enforce or disallow capitalization of the first letter of a comment
    'capitalized-comments': 'off', // TODO

    // require or disallow trailing commas
    'comma-dangle': [
        'warn',
        {
            arrays: 'always-multiline',
            objects: 'always-multiline',
            imports: 'always-multiline',
            exports: 'always-multiline',
            functions: 'always-multiline',
        },
    ],

    // enforce spacing before and after comma
    // REF typescript
    'comma-spacing': ['error', { before: false, after: true }],

    // enforce one true comma style
    'comma-style': ['error', 'last'],

    // require or disallow padding inside computed properties
    'computed-property-spacing': ['error', 'never', { enforceForClassMembers: true }],

    // enforce consistent naming when capturing the current execution context
    'consistent-this': 'off', // TODO

    // enforce newline at the end of file , with no multiple empty lines
    'eol-last': 'error',

    // require or disallow spacing between function identifiers and their invocations
    // REF typescript
    'func-call-spacing': ['error', 'never'],

    // require function names to match the name of the variable or property to which they are assigned
    'func-name-matching': 'error',

    // require function expressions to have a name
    'func-names': 'off', // TODO

    // enforce use of function declarations or expressions
    'func-style': 'off', // TODO really not sure about this one

    // enforce line breaks between arguments of a function call
    'function-call-argument-newline': ['error', 'consistent'],

    // enforce consistent line breaks inside function parentheses
    'function-paren-newline': ['error', 'consistent'], // TODO multiline?

    // blacklist certain identifiers to prevent them being used
    'id-blacklist': 'off',

    // this option enforces minimum and maximum identifier lengths (variable names, property names etc.)
    'id-length': 'off',

    // require identifiers to match the provided regular expression
    'id-match': 'off',

    // enforce the location of arrow function bodies
    'implicit-arrow-linebreak': ['warn', 'beside'],

    // specify tab or space width for your code
    // REF typescript
    indent: [
        'error',
        4,
        {
            SwitchCase: 1,
            VariableDeclarator: 'first',
        },
    ],

    // specify whether double or single quotes should be used in JSX attributes
    'jsx-quotes': ['error', 'prefer-double'],

    // enforce spacing between keys and values in object literal properties
    'key-spacing': [
        // TODO
        'error',
        {
            // align: value,
            beforeColon: false,
            afterColon: true,
            mode: 'minimum',
        },
    ],

    // enforce spacing before and after keywords
    // REF typescript
    'keyword-spacing': ['error', { before: true, after: true }],

    // enforce position of line comments
    'line-comment-position': 'off', // TODO

    // disallow mixed 'LF' and 'CRLF' as linebreaks
    'linebreak-style': ['error', 'unix'],

    // require empty lines around comments
    // https://github.com/eslint/eslint/issues/2965
    'lines-around-comment': [
        'off', // TODO 1
        {
            beforeBlockComment: true,
            afterBlockComment: false,
            beforeLineComment: true,
            afterLineComment: false,
            allowBlockStart: true,
            allowBlockEnd: false,
            allowObjectStart: true,
            allowObjectEnd: false,
            allowArrayStart: true,
            allowArrayEnd: false,
            allowClassStart: true,
            allowClassEnd: true,
        },
    ],

    // require or disallow an empty line between class members
    // REF typescript
    'lines-between-class-members': ['error', 'always', { exceptAfterSingleLine: false }],

    // specify the maximum depth that blocks can be nested
    'max-depth': 'off',

    // specify the maximum length of a line in your program
    'max-len': 'off', // TODO

    // enforce a maximum file length
    'max-lines': 'off',

    // enforce a maximum number of line of code in a function
    'max-lines-per-function': 'off',

    // specify the maximum depth callbacks can be nested
    'max-nested-callbacks': 'off',

    // limits the number of parameters that can be used in the function declaration.
    'max-params': 'off',

    // specify the maximum number of statement allowed in a function
    'max-statements': 'off',

    // specify the maximum number of statements allowed per line
    'max-statements-per-line': ['error', { max: 1 }],

    // enforce a particular style for multiline comments
    'multiline-comment-style': 'off',

    // enforce newlines between operands of ternary expressions
    'multiline-ternary': ['warn', 'always-multiline'], // TODO

    // require a capital letter for constructors
    // REF babel
    'new-cap': ['error', { newIsCap: true, capIsNew: false }],

    // disallow the omission of parentheses when invoking a constructor with no arguments
    'new-parens': 'error', // TODO

    // enforce newline after each call when chaining the calls
    'newline-per-chained-call': ['error', { ignoreChainWithDepth: 3 }], // TODO

    // disallow use of the `Array` constructor
    // REF typescript
    'no-array-constructor': 'error',

    // disallow use of bitwise operators
    'no-bitwise': 'error',

    // disallow use of the `continue` statement
    'no-continue': 'error', // TODO

    // disallow comments inline after code
    'no-inline-comments': 'off', // TODO

    // disallow `if` as the only statement in an `else` block
    'no-lonely-if': 'off', // TODO

    //  disallow mixes of different operators
    'no-mixed-operators': 'error',

    // disallow mixed spaces and tabs for indentation
    'no-mixed-spaces-and-tabs': 'error',

    // disallow use of chained assignment expressions
    'no-multi-assign': 'error',

    // disallow multiple empty lines
    'no-multiple-empty-lines': [
        0, // TODO BROKEN 2
        {
            max: 2,
            maxEOF: 1,
        },
    ],

    // disallow negated conditions
    'no-negated-condition': 'off', // TODO

    // disallow nested ternary expressions
    'no-nested-ternary': 'error',

    // disallow the use of the `Object` constructor
    'no-new-object': 'error',

    // disallow use of unary operators, `++` and `--`
    'no-plusplus': 'off', // TODO

    // disallow use of certain syntax in code
    'no-restricted-syntax': 'off', // TODO

    // disallow tabs in file
    'no-tabs': 'error',

    // disallow the use of ternary operators
    'no-ternary': 'off', // TODO

    // disallow trailing whitespace at the end of lines
    'no-trailing-spaces': ['error', { skipBlankLines: false }],

    // disallow dangling underscores in identifiers
    'no-underscore-dangle': 'off', // TODO

    // disallow the use of ternary operators when a simpler alternative exists
    'no-unneeded-ternary': ['error', { defaultAssignment: false }], // TODO

    // disallow whitespace before properties
    'no-whitespace-before-property': 'error',

    // enforce the location of single-line statements
    'nonblock-statement-body-position': ['error', 'below'],

    // enforce consistent line breaks inside braces
    'object-curly-newline': [
        // TODO
        'off',
        {
            ObjectExpression: {
                multiline: true,
                // minProperties: 1,
            },
            ObjectPattern: {
                multiline: true,
            },
        },
    ],

    // require or disallow padding inside curly braces
    // REF babel
    'object-curly-spacing': ['error', 'always'], // TODO

    // enforce placing object properties on separate lines
    'object-property-newline': ['warn', { allowAllPropertiesOnSameLine: false }], // TODO

    // require or disallow one variable declaration per function
    'one-var': ['error', 'never'], // TODO

    // require or disallow an newline around variable declarations
    'one-var-declaration-per-line': ['error', 'always'],

    // require assignment operator shorthand where possible or prohibit it entirely
    'operator-assignment': 'off', // TODO 1

    // enforce operators to be placed before or after line breaks
    'operator-linebreak': [
        // TODO
        'warn',
        'after',
        {
            overrides: {
                '?': 'before',
                ':': 'before',
            },
        },
    ],

    // enforce padding within blocks
    'padded-blocks': [
        'error',
        {
            blocks: 'never',
            classes: 'never',
            switches: 'never',
        },
        { allowSingleLineBlocks: true },
    ],

    // require or disallow padding lines between statements
    'padding-line-between-statements': 'off', // TODO

    // disallow the use of `Math.pow` in favor of the `**` operator
    'prefer-exponentiation-operator': 'off', // TODO

    // disallow using Object.assign with an object literal as the first argument and prefer the use of object spread instead.
    'prefer-object-spread': 'error',

    // require quotes around object literal property names
    'quote-props': [
        // TODO
        'error',
        'as-needed',
        {
            keywords: false,
            unnecessary: true,
            numbers: false,
        },
    ],

    // specify whether backticks, double or single quotes should be used
    // REF babel
    // REF typescript
    quotes: [
        // TODO
        'error',
        'single',
        {
            avoidEscape: true,
            allowTemplateLiterals: true,
        },
    ],

    // require or disallow use of semicolons instead of ASI
    // REF babel
    // REF typescript
    semi: ['error', 'always'],

    // enforce spacing before and after semicolons
    'semi-spacing': ['error', { before: false, after: true }],

    // enforce location of semicolons
    'semi-style': ['error', 'last'],

    // requires object keys to be sorted
    'sort-keys': 'off', // TODO

    // sort variables within the same declaration block
    'sort-vars': 'off', // TODO

    // require or disallow a space before blocks
    'space-before-blocks': 'error',

    // require or disallow a space before function opening parenthesis
    // REF typescript
    'space-before-function-paren': [
        // TODO
        'error',
        {
            anonymous: 'always', // TODO never?
            named: 'never',
            asyncArrow: 'always',
        },
    ],

    // require or disallow spaces inside parentheses
    'space-in-parens': ['error', 'never'],

    // require spaces around operators
    'space-infix-ops': 'error',

    // require or disallow spaces before/after unary operators
    'space-unary-ops': 'error',

    // require or disallow a space immediately following the `//` or `/*` in a comment
    'spaced-comment': [
        // TODO
        'error',
        'always',
        {
            exceptions: ['-', '=', '+', '/', '*'],
            markers: ['=', '!', '/'],
            // line: { exceptions: ['-', '='] },
            // block: { balanced: true },
        },
    ],

    // enforce spacing around colons of switch statements
    'switch-colon-spacing': ['error', { after: true, before: false }],

    // require or disallow spacing between template tags and their literals
    'template-tag-spacing': ['error', 'never'],

    // require or disallow the Unicode BOM
    'unicode-bom': ['error', 'never'],

    // require regex literals to be wrapped in parentheses
    'wrap-regex': 'error',
};

module.exports = {
    rules,
};
